@@ -1,5 +1,5 @@
-# $Id: Twofish.pm,v 2.10 2001/05/07 07:17:33 ams Exp $
-# Copyright 2001 Abhijit Menon-Sen <ams@wiw.org>
+# $Id: Twofish.pm,v 2.12 2001/05/21 17:38:01 ams Exp $
+# Copyright 2001 Abhijit Menon-Sen <ams@toroid.org>
 
 package Crypt::Twofish;
 
@@ -9,7 +9,7 @@ use DynaLoader;
 use vars qw( @ISA $VERSION );
 
 @ISA = qw( DynaLoader );
-($VERSION) = q$Revision: 2.10 $ =~ /([\d.]+)/;
+$VERSION = '2.14';
 
 bootstrap Crypt::Twofish $VERSION;
 
@@ -97,7 +97,7 @@ and free for all uses, as described at
 This module implements Twofish encryption. It supports the Crypt::CBC
 interface, with the functions described below. It also provides an
 interface that is call-compatible with Crypt::Twofish 1.0, but its use
-is strongly discouraged.
+in new code is strongly discouraged.
 
 =head2 Functions
 
@@ -151,9 +151,9 @@ platforms, and suggesting that I probe for features via %Config.
 
 =head1 AUTHOR
 
-Abhijit Menon-Sen <ams@wiw.org>
+Abhijit Menon-Sen <ams@toroid.org>
 
-Copyright 2001 Abhijit Menon-Sen. All rights reserved.
+Copyright 2001 Abhijit Menon-Sen.
 
-This software is distributed under the terms of the Artistic License
-<URL:http://ams.wiw.org/code/artistic.txt>.
+This module is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
